@@ -153,7 +153,7 @@ bool WavFile::open(AudioConfig &cfg)
     // We need to make a buffer for the user
     try
     {
-        _sampleBuffer = new short[bufSize];
+        _sampleBuffer = new short[bufSize/2];
     }
     catch (std::bad_alloc const &ba)
     {
